#!/usr/bin/env python
# $Id: setup.py.in 696 2020-02-11 18:59:06Z toni $
# This script isn't used directly to generate the distributed files
# since some files are generated from the source and the zip and tar.gz
# differ.
# GNU Make is used instead.

from distutils.core import setup
import distutils.command.install_scripts
import shutil

class my_install(distutils.command.install_scripts.install_scripts):
    ''' Rename scripts that use the .py extension after installation.
    NOTE: breaks bdist_rpm
    Reference: http://stackoverflow.com/questions/4359231/rename-script-file-in-distutils
    '''
    def run(self):
        distutils.command.install_scripts.install_scripts.run(self)
        for script in self.get_outputs():
            if script.endswith('.bash'):
                shutil.move(script, script[:-5])
            elif script.endswith('.py'):
                shutil.move(script, script[:-3])

setup(name='relevation',
      version='1.3.1',
      author='Toni Corvera',
      author_email='outlyer@gmail.com',
      url='http://p.outlyer.net/relevation',
      description='Command-line interface to query Revelation files',
      long_description=
      '''This is a command-line tool capable of retrieving passwords from a Revelation password file.

Please note files can only be searched, not edited with this tool.''',
      license='BSD',
      package_dir={'': 'src'},
      packages=['relevation'],
      scripts=['src/relevation.bash'],
      cmdclass = {"install_scripts": my_install}, # hook
      data_files=[
                  ('share/man/man1', ['relevation.1']),
                  #('share/doc/relevation', ['CHANGELOG']),
                  ('share/doc/relevation/extra', ['devtools/checkpw.py','devtools/genpw.py']),
                 ]
      )

# vim:set ts=4 et ai: #
